@@ -8,20 +8,15 @@ usage() {
 	echo <<EOF
 Usage: $name [options...]"
 Options:
-  --sandbox       Translate a sandboxed PyPy
   --python=PYTHON Use PYTHON to tranlate PyPy
 
 EOF
 }
 
-SANDBOX=0
 PYTHON=python
 
 while [ $# -ge 1 ]; do
 	case "$1" in
-	--sandbox)
-		SANDBOX=1
-		;;
 	--python)
 		PYTHON="$2"
 		shift
@@ -46,8 +41,6 @@ OPT=3
 ROOTFINDER=shadowstack
 if echo "$DEB_BUILD_OPTIONS" | egrep -q '\bnoopt\b'; then
 	OPT=0
-elif [ $SANDBOX -gt 0 ]; then
-	OPT=2
 elif dpkg-architecture -iany-i386; then
 	OPT=jit
 	ROOTFINDER=asmgcc
@@ -70,10 +63,6 @@ elif dpkg-architecture -iany-s390x; then
 fi
 RPYOPTS="$RPYOPTS --opt=$OPT --no-shared"
 
-if [ $SANDBOX -gt 0 ]; then
-	RPYOPTS="$RPYOPTS --sandbox --gc=generation"
-	ROOTFINDER=shadowstack
-fi
 if [ $OPT = "mem" -o $OPT = "jit" -o $OPT = 2 -o $OPT = 3 ]; then
 	RPYOPTS="$RPYOPTS --gcrootfinder=$ROOTFINDER"
 fi
@@ -84,13 +73,19 @@ if dpkg-architecture -iany-i386 \
    || dpkg-architecture -iany-arm \
    || dpkg-architecture -iany-mips64el \
    || dpkg-architecture -iany-ppc64 \
-   || dpkg-architecture -iany-ppc64el; then
+   || dpkg-architecture -iany-ppc64el \
+   || dpkg-architecture -iany-s390x; then
 	CONTINUATION=1
 fi
 if [ $CONTINUATION -eq 0 ]; then
 	TARGETOPTS="$TARGETOPTS --withoutmod-_continuation"
 fi
 
+if dpkg-architecture -iany-s390x; then
+	# Target the oldest s390x supported by upstream
+	export CFLAGS="$CFLAGS -march=z10"
+fi
+
 if echo "$PYTHON" | grep -Fq pypy; then
 	if [ $(dpkg-architecture -q DEB_HOST_ARCH_BITS) -eq 32 ]; then
 		export PYPY_GC_MAX_DELTA=200MB
